<a id="aea.helpers.constants"></a>

# aea.helpers.constants

Module with helpers constants.

<a id="aea.helpers.constants.NETWORK_REQUEST_DEFAULT_TIMEOUT"></a>

#### NETWORK`_`REQUEST`_`DEFAULT`_`TIMEOUT

in seconds

